@@ -114,6 +114,8 @@ static GtkWidget *etree_cd_length_entry = NULL;
 static char *config_filename = NULL;
 
 /* Window and pane sizes. */
+static int main_window_xpos = -1;
+static int main_window_ypos = -1;
 static int main_window_width = -1;
 static int main_window_height = -1;
 static int vpane1_position = -1;
@@ -343,6 +345,26 @@ char *audio_options_get_output_device()
     return "";
 }
 
+int appconfig_get_main_window_xpos()
+{
+    return main_window_xpos;
+}
+
+void appconfig_set_main_window_xpos(int x)
+{
+    main_window_xpos = x;
+}
+
+int appconfig_get_main_window_ypos()
+{
+    return main_window_ypos;
+}
+
+void appconfig_set_main_window_ypos(int x)
+{
+    main_window_ypos = x;
+}
+
 int appconfig_get_main_window_width()
 {
     return main_window_width;
@@ -822,7 +844,7 @@ void appconfig_show(GtkWidget *main_window)
         gtk_combo_box_set_active(GTK_COMBO_BOX(combo_box), pos);
     }
 #endif
-    gtk_widget_set_sensitive( GTK_WIDGET(combo_box), sample_get_playing()?FALSE:TRUE);
+    gtk_widget_set_sensitive( GTK_WIDGET(combo_box), sample_is_playing()?FALSE:TRUE);
     gtk_table_attach(GTK_TABLE(table), combo_box,
             1, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 5, 0);
     g_signal_connect(G_OBJECT(combo_box), "changed",
@@ -835,7 +857,7 @@ void appconfig_show(GtkWidget *main_window)
 
     output_device_entry = gtk_entry_new();
     gtk_entry_set_text(GTK_ENTRY(output_device_entry), audio_options_get_output_device());
-    gtk_widget_set_sensitive( GTK_WIDGET(output_device_entry), sample_get_playing()?FALSE:TRUE);
+    gtk_widget_set_sensitive( GTK_WIDGET(output_device_entry), sample_is_playing()?FALSE:TRUE);
     gtk_table_attach(GTK_TABLE(table), output_device_entry,
             1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 5, 0);
 
@@ -974,6 +996,16 @@ static int appconfig_read_file() {
             nkey = atoi((char *)key);
             set_audio_function_pointers_with_index(nkey);
             xmlFree(key);
+        } else if (!(xmlStrcmp(cur->name, (const xmlChar *) "main_window_xpos"))) {
+            key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
+            nkey = atoi((char *)key);
+            appconfig_set_main_window_xpos(nkey);
+            xmlFree(key);
+        } else if (!(xmlStrcmp(cur->name, (const xmlChar *) "main_window_ypos"))) {
+            key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
+            nkey = atoi((char *)key);
+            appconfig_set_main_window_ypos(nkey);
+            xmlFree(key);
         } else if (!(xmlStrcmp(cur->name, (const xmlChar *) "main_window_width"))) {
             key = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
             nkey = atoi((char *)key);
@@ -1128,6 +1160,30 @@ int appconfig_write_file() {
         return 3;
     }
 
+    sprintf(tmp_str, "%d", appconfig_get_main_window_xpos());
+    cur = xmlNewChild(root, NULL, (const xmlChar *)"main_window_xpos",
+        (const xmlChar *) tmp_str);
+
+    if (cur == NULL) {
+        fprintf(stderr, "error creating wavbreaker config file\n");
+        fprintf(stderr, "error creating main_window_xpos node\n");
+        xmlFreeNodeList(root);
+        xmlFreeDoc(doc);
+        return 3;
+    }
+
+    sprintf(tmp_str, "%d", appconfig_get_main_window_ypos());
+    cur = xmlNewChild(root, NULL, (const xmlChar *)"main_window_ypos",
+        (const xmlChar *) tmp_str);
+
+    if (cur == NULL) {
+        fprintf(stderr, "error creating wavbreaker config file\n");
+        fprintf(stderr, "error creating main_window_ypos node\n");
+        xmlFreeNodeList(root);
+        xmlFreeDoc(doc);
+        return 3;
+    }
+
     cur = xmlNewChild(root, NULL, (const xmlChar *)"etree_filename_suffix",
         (const xmlChar *) get_etree_filename_suffix());
 
