@@ -42,6 +42,7 @@ SampleInfo sampleInfo;
 static AudioFunctionPointers *audio_function_pointers;
 static unsigned long sample_start = 0;
 static int playing = 0;
+static int writing = 0;
 static gboolean kill_play_thread = FALSE;
 static int audio_type;
 
@@ -93,11 +94,6 @@ void sample_set_error_message(const char *val)
     strncpy(error_message, val, ERROR_MESSAGE_SIZE);
 }
 
-gint sample_get_playing()
-{
-    return playing;
-}
-
 void sample_init()
 {
     mutex = g_mutex_new();
@@ -201,6 +197,11 @@ int sample_is_playing()
     return playing;
 }
 
+int sample_is_writing()
+{
+    return writing;
+}
+
 int play_sample(gulong startpos, gulong *play_marker)
 {       
     g_mutex_lock(mutex);
@@ -588,6 +589,7 @@ write_thread(gpointer data)
 
     fclose(write_sample_fp);
 
+    writing = 0;
     return NULL;
 }
 
@@ -597,13 +599,17 @@ void sample_write_files(GList *tbl, WriteInfo *write_info, char *outputdir)
     wtd.write_info = write_info;
     wtd.outputdir = outputdir;
 
+    writing = 1;
+
     if (sample_file == NULL) {
         perror("Must open file first\n");
+        writing = 0;
         return;
     }
 
     if ((write_sample_fp = fopen(sample_file, "rb")) == NULL) {
         printf("error opening %s\n", sample_file);
+        writing = 0;
         return;
     }
 
@@ -611,6 +617,7 @@ void sample_write_files(GList *tbl, WriteInfo *write_info, char *outputdir)
     thread = g_thread_create(write_thread, &wtd, FALSE, NULL);
     if (thread == NULL) {
         perror("Return from g_thread_create was NULL");
+        writing = 0;
         return;
     }
     /* end new thread stuff */
