@@ -51,12 +51,12 @@ char * sample_get_audio_dev();
 char * sample_get_sample_file();
 
 int sample_is_playing();
+int sample_is_writing();
 int play_sample(gulong, gulong *);
 void stop_sample();
 int sample_open_file(const char *, GraphData *, double *);
 void sample_close_file();
 void sample_write_files(GList *, WriteInfo *, char *);
-gint sample_get_playing();
 void sample_merge_files(char *merge_filename, GList *filenames, WriteInfo *write_info);
 
 #endif /* SAMPLE_H*/
