@@ -82,6 +82,12 @@ void wavbreaker_quit();
 
 extern char *sample_filename;
 
+enum {
+    CHECK_ALL = 0,
+    CHECK_NONE,
+    CHECK_INVERT
+};
+
 #define MB_OVL_MOODBAR 2
 #define MB_OVL_WAVEFORM 7
 #define MOODBAR_BLEND(waveform,moodbar) (((MB_OVL_WAVEFORM*waveform+MB_OVL_MOODBAR*moodbar))/(MB_OVL_MOODBAR+MB_OVL_WAVEFORM))
